#
# spec file for package gstreamer-plugins-vaapi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gst_branch 1.0

Name:           gstreamer-plugins-vaapi
Version:        1.8.3
Release:        3.2
Summary:        Gstreamer VA-API plugins
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Other
Url:            https://gstreamer.freedesktop.org/
Source0:        https://gstreamer.freedesktop.org/src/gstreamer-vaapi/gstreamer-vaapi-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  libva-devel
BuildRequires:  pkgconfig
BuildRequires:  yasm
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.8.0
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= 1.8.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.8.0
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-drm)
BuildRequires:  pkgconfig(libva-egl)
BuildRequires:  pkgconfig(libva-wayland)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(wayland-client) >= 1.0.2
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
ExclusiveArch:  %ix86 x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      libgstcodecparsers_vpx0
Obsoletes:      libgstvaapi-1_6-1
Obsoletes:      libgstvaapi-drm
Obsoletes:      libgstvaapi-egl
Obsoletes:      libgstvaapi-glx
Obsoletes:      libgstvaapi-wayland
Obsoletes:      libgstvaapi-x11

%description
gstreamer-vaapi is a collection of GStreamer plugins and helper libraries that allow hardware accelerated video decoding through VA-API.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package doc
Summary:        Documentation for gstreamer-plugins-vaapi
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description doc
This package contains documentation for gstreamer-plugins-vaapi.

%prep
%setup -q -n gstreamer-vaapi-%{version}

%build
%configure \
	--disable-static \
	--enable-egl \
	--enable-encoders \
	--enable-drm \
	--enable-glx \
	--enable-opengl \
	--enable-wayland \
	--enable-x11 \

make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,0755)
%doc AUTHORS COPYING.LIB NEWS README
%{_libdir}/gstreamer-%{gst_branch}/libgstvaapi.so

%files doc
%defattr(-, root, root)
%{_datadir}/gtk-doc/html/gstreamer-vaapi-plugins-1.0

%changelog
* Mon Aug 22 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Bugs fixed: bgo#769250, bgo#768458, bgo#769237, bgo#768458,
    bgo#768544, bgo#767946, bgo#767934, bgo#767699, bgo#766184,
    bgo#765368.
* Tue Jun 14 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + bgo#765702: build: errors when compiling without X11.
* Sat May 28 2016 zaitor@opensuse.org
- Add pkgconfig(libva-drm), pkgconfig(libva-egl) and
  pkgconfig(libva-wayland): Ensure that all the libva-subpackages
  are available during build.
* Wed Apr 20 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#764231 : Bad call to
    gst_buffer_add_video_gl_texture_upload_meta() in
    gstvaapivideometa_texture.c.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Update Url and Source to new home at freedesktop.org.
- Pass --enable-egl, --enable-encoders, --enable-drm,
  - -enable-opengl, --enable-wayland and --enable-x11 to configure
  to ensure we build support for them.
- Bump soname following upstream changes.
- Add Mesa-libGLESv3-devel, pkgconfig(gl), pkgconfig(libdrm),
  pkgconfig(libudev), pkgconfig(libva), pkgconfig(libva-x11),
  pkgconfig(vpx) BuildRequires: New explicit dependencies.
- Drop libgstcodecparsers_vpx0, libgstvaapi-1_6-1, libgstvaapi-drm,
  libgstvaapi-egl, libgstvaapi-glx, libgstvaapi-wayland and
  libgstvaapi-x11 sub-packages and obsolete them.
- Add new doc sub-package.
* Thu Dec 24 2015 zaitor@opensuse.org
- Update to version 0.7.0:
  + Add VP9 Decoder.
  + Improvements to HEVC(H265) decoder:
  - Fix the decoding of dependent slice segment.
  - Fix decoding of stream when it has temporal sublayers.
  - Added Workaround to recognize wrongly encoded main profile
    streams.
  - Add SEI Header parsing.
  - Fix the value assigning for delta_chroma_log2_weight_denom.
  - Fix default value assignment of pred_weight_table.
  - Fix ChromaOffsetL0/ChromaOffsetL1 calculation.
  - Add calculation of WpOffsetHalfRangeC.
  - Fix the scaling list scan order.
  - Fix the picture addition in dpb() based on spec H265 v3.
  - Fix the dpb_add() based on C.5.2.3.
  - Fix flushing of dpb for EOS/EOB nal.
  + Added infrastructure for handling corrupted pictures in h264
    decoder (bgo#703921, bgo#751434).
  + Add number of fixes and optimizations to GstContext sharing
    (bgo#757598).
  + Add API for dynamic detection of OpenGL API in use
    (bgo#753099).
  + Make vaapidecode + glimagesink combination work with opengl3
    (bgo#753099).
  + Fix segfault in vaapipostproc (bgo#752558).
  + Fix seeking while using GLTextureUpload for rendering
    (bgo#752929).
  + Ported JPEG decoder to new API/ABI changes in codecparser.
  + Removed gstvaapiuploader (bgo#752777).
  + Fix 0/1 frame-rate handling in encoder (bgo#744042).
  + Validate chroma sampling according to the VA's RT format in
    Encoder (bgo#744042).
  + Number of improvements in vaapi video memory handling
    (bgo#744042).
  + Stabilization of vaapidecodebin (bgo#749554, bgo#757957).
  + Wayland fixes: Don't return GST_FLOW_ERROR on flushing
    (bgo#753598).
  + Add yasm as build dependency.
  + Remvoved custom(non-official) debian parallel compilation
    option.
  + Fix multi-resolution video handling in vaapidecode
    (bgo#753914).
  + Adding stereoscopic/multiview upstream API support
    (bgo#750835).
  + Fixed fps calculation for for forced latency framerate
    (bgo#755040).
  + Fix build issues while disabling built-in codecparsers
    (bgo#754845).
  + Mark support for GStreamer 1.2 as obsolete.
  + Update libvpx submodule to 1.4.0.
  + Fix caps negotiation for meta:GstVideoGLTextureUploadMeta
    (bgo#756686).
  + Fixed leaked display instance in vaapidecodebin (bgo#757595).
* Tue Oct 27 2015 zaitor@opensuse.org
- Stop using wayland bcond, it does not work out for us.
- Add new %%define gst_so and %%define gst_ver and use suse_version
  to decide the value of these. Allowing package to be built with
  the different branches of gstreamer existing in older versions of
  openSUSE.
- Following this, subpackages get new name depending on what
  gst-branch they are built against.
* Tue Oct 20 2015 zaitor@opensuse.org
- Update to version 0.6.1:
  + Fix a possible segmentation fault using gstreamer 1.4
    (bgo#752558).
  + Don't loose the GLTextureUpload meta on seek (bgo#752929).
  + Remove in debian rules the option --with-gstreamer-api
    (bgo#753618).
  + Add in debian rules yasm as dependency.
  + Keep a copy of input codec state (bgo#753914).
  + Renegotiate if the input caps are not equal (bgo#750835).
  + Fix the FPS denominator and numerator (bgo#755040).
  + Initialize H264 PPS's slice_group_id (bgo#754845).
  + Verify for H264 MVC and H265 SPS when running configure
    (bgo#754845).
  + Link libgstvaapi_parse.so against libgstcodecparsers.so.
- Stop passing --with-gstreamer-api=1.0 to configure, no longer
  recognized.
* Mon Jul 20 2015 zaitor@opensuse.org
- Correct %%bconds, fixes build on SLE12 and openSUSE42 where we do
  not have wayland.
- Clean up spec.
- Update URL to new home.
* Fri Jul 17 2015 zaitor@opensuse.org
- Update to version 0.6.0:
  + Major changes:
  - Add HEVC(H265) Decoder.
  - Add HEVC(H265) Encoder.
  - Add VP8 Encoder.
  - Add JPEG Encoder.
  - Add a vaapidecodebin(vaapidecode->queue->vaapipostproc)
    element.
  - Add support for EGL.
  - Add Skin-Tone-Enhancement feature in vaapipostproc.
  - Add support for H.264 Multiview High profile encoding with
    more than 2 views.
  + Other Changes of interest:
  - Add support for loss of pictures in h264 decoder.
  - Add support for GstVideoGLTextureOrientation in plugins.
  - Add support for BGRA textures in plugins.
  - Add a simple-encoder test program that uses libgstvaapi for
    video encoding to elementary streams.
  - Add finer wayland frame control and many other optimizations.
  - Add packed SEI header message support in h264 encoder for CBR
    mode.
  - Add scaling of quality factor and Quantization tables for
    JPEG encoder.
  - Add GstColorBalance interface in vaapipostproc.
  - Add a handoff signal to vaapisink.
  - Add rounding control handling for VC1 simple and Main
    profile.
  - Record glconext supplied by downstream to enable run-time
    compatibility check.
  - Switch back to single thread implementation in vaapidecode.
  - Set decoding latency in vaapidecode by assuming realtime
    performance for the HW decoding.
  - Allow vaapidecode to connect with glimagesink, mark x11
    display as compatible with EGL.
  - Allow decoding of VC1 streams which contain user BDUs.
  - Use git.mk, a small Makefile to autogenerate .gitignore
    files.
  - Expose the overlay capability in vaapisink for compatibility
    with dvbsuboverlay.
  - Expose deinterlace property to vaapidecodebin.
  - Enable VPP element in vaapidecodebin only if there is HW
    support.
  - Fix autoplugging of vaapidecode in playbin for wmv/asf
    streams.
  - Fix multi-slice hevc encoding.
  - Fix ABBA deadlock between vaapisink and vaapipostproc if
    running in different threads.
  - Fix Seeking failure while using navseek in pipeline.
  - Fix PTS cache for MPEG2 GOP start.
  - Fix the wrong selection of passthrough mode in vaapipostproc.
  - Fix GstVaapiVideoPool related dead-lock.
  - Fix the race condition while setting drm device type.
  - Fix crash in vaapidecode if buffer outlives the decoder.
  - Fix memory leak in vaapidecode.
  - Fix multiple caps negotiation issues with vaapi elements.
  - Improve check for upstream element that requires DMABUF
    buffer pool.
  - Fix vaapisink memory leak in debug mode.
  - Fix crash when seeking mpeg2 strems.
  - Fix support for Wayland/EGL running alongside X11 (around 70+
    bug reports fixed).
  + GStreamer support corner:
  - Removed the support for GStreamer 0.10 and 1.0
  - GStreamer >= 1.2 is the minimal requirement
  - GStreamer 1.2.x is deprecated, and will be obsoleted in a
    future release
- Add a define soname and set it to 2, following upstream changes.
  Rename all sub-packages to get the new soname.
* Sun Mar 29 2015 zaitor@opensuse.org
- Update to version 0.5.10:
  + Add support for DRM Render-Nodes for headless operation.
  + Add support for VA surface buffer sharing with DMABUF and GEM
    handles.
  + Add support for v4l2src with io-mode={dmabuf,dmabuf-import}.
  + Drop support for VA/GLX specific APIs in libgstvaapi and
    vaapisink (bgo#736711).
  + Improvements to H.264 codecs:
  - Fix profile limits for encoding.
  - Fix pixel-aspect-ratio in the encoded stream.
  - Add decoding support for interlaced streams with
    repeat-first-field (RFF).
  - Fix decoding of interlaced streams in top-field-first order
    (TFF) (bgo#739291).
  - Fix decoding of UK DVB-T2 streams (bgo#739291).
  + Improvements to plugin elements:
  - Add support for dma_buf imports (Wind Yuan) (bgo#735362).
  - Allow for SW decoding fallbacks with unsupported profiles
    (bgo#730997).
  - Make vaapipostproc work with SW elements (bgo#720174,
    bgo#704078).
  - Allow vaapipostproc to integrate with GL downstream elements
    (bgo#735231).
  - Add support for high-quality scaling to vaapipostproc
    ("scale-method=hq").
  - Fix advanced deinterlacing when it is the unique filter
    applied.
  - Add GstColorBalance interface to vaapisink (bgo#722390).
  - Implement the GstNavigation interface into vaapisink
    (bgo#711479).
  - Allow rescaling of X11 window for vaapisink (bgo#711478).
  - Optimizations to vaapidecode thread handling (bgo#734616).
  - Fix deinterlacing from non VA memory buffers (bgo#726270).
  - Fix clearing of subtitle overlay.
  - Fix clearing of vaapipostproc state during restart.
- Bump soname following upstream changes.
* Sat Dec 13 2014 zaitor@opensuse.org
- Add pkgconfig(xrender) and pkgconfig(xrandr) BuildRequires: They
  were missing from the inital build.
* Tue Dec  9 2014 zaitor@opensuse.org
- Initial packaging.
